@@ -4,5 +4,5 @@ from abc import ABC, abstractmethod
 class EventBase(ABC):
 
     @abstractmethod
-    def dispatch(self, event_name, event_data, event_data_type):
+    def dispatch(self, event_name, event_data):
         pass
\ No newline at end of file
